# Country Shape Quiz

## Name the country from its shape!! 
This is a Python quiz application that allows users to take a quiz with questions displayed alongside images. 
Users can input their answers, and the application will provide feedback on whether the answers are correct or not. 

![alt text](images/screenshot1.png)


All the images are imported from geojson files obtained from [https://geojson-maps.ash.ms/](https://geojson-maps.ash.ms/), 
[geoBoundaries](https://www.geoboundaries.org/index.html) 
and [https://maps.princeton.edu/catalog/stanford-sn252ts8433](https://maps.princeton.edu/catalog/stanford-sn252ts8433) 
